@@ -19,7 +19,10 @@ Read napalm.readthedocs.org for more information.
 """
 
 # std libs
-import re
+try:
+    import regex as re
+except ModuleNotFoundError:
+    import re
 import time
 import inspect
 
@@ -490,7 +493,8 @@ class EOSDriver(NetworkDriver):
             )
 
             interfaces[interface]["mtu"] = int(values["mtu"])
-            interfaces[interface]["speed"] = int(values["bandwidth"] * 1e-6)
+            #            interfaces[interface]["speed"] = float(values["bandwidth"] * 1e-6)
+            interfaces[interface]["speed"] = float(values["bandwidth"] / 1000000.0)
             interfaces[interface]["mac_address"] = napalm.base.helpers.convert(
                 napalm.base.helpers.mac, values.pop("physicalAddress", "")
             )
@@ -1005,6 +1009,10 @@ class EOSDriver(NetworkDriver):
                     bgp_neighbors[peer_address] = default_neighbor_dict(local_as)
                 if options[0] == "peer-group":
                     bgp_neighbors[peer_address]["__group"] = options[1]
+                # EOS > 4.23.0 only supports the new syntax
+                # https://www.arista.com/en/support/advisories-notices/fieldnotices/7097-field-notice-39
+                elif options[0] == "peer" and options[1] == "group":
+                    bgp_neighbors[peer_address]["__group"] = options[2]
 
                 # in the config, neighbor details are lister after
                 # the group is specified for the neighbor:
@@ -2006,6 +2014,7 @@ class EOSDriver(NetworkDriver):
         size=c.PING_SIZE,
         count=c.PING_COUNT,
         vrf=c.PING_VRF,
+        source_interface=c.PING_SOURCE_INTERFACE,
     ):
         """
         Execute ping on the device and returns a dictionary with the result.
@@ -2036,6 +2045,8 @@ class EOSDriver(NetworkDriver):
         command += " repeat {}".format(count)
         if source != "":
             command += " source {}".format(source)
+        if source_interface != "":
+            command += " interface {}".format(source_interface)
 
         commands.append(command)
         output = self.device.run_commands(commands, encoding="text")[-1]["output"]
