@@ -1,5 +1,5 @@
 from lxml import etree
 
 
-def xml_to_string(xml_object):
+def xml_to_string(xml_object: etree.Element) -> str:
     return etree.tostring(xml_object).decode()
